libchromeos: Move Dictionary class into its own header file

Moved chromeos::dbus_utils::Dictionary type alias into its
own header file (chromeos/dictionary.h) and promoting it to the
top level namespace (chromeos).

So now it becomes chromeos::VariantDictionary and it is now
independent from D-Bus data serialization.

BUG=None
TEST=FEATURE=test emerge-link libchromeos buffet

Change-Id: Ibad63fd4168d77b9a4b80c7800016510f87ae33d
Reviewed-on: https://chromium-review.googlesource.com/219413
Reviewed-by: Alex Vakulenko <avakulenko@chromium.org>
Tested-by: Alex Vakulenko <avakulenko@chromium.org>
Commit-Queue: Alex Vakulenko <avakulenko@chromium.org>
diff --git a/buffet/commands/schema_utils.cc b/buffet/commands/schema_utils.cc
index 4106511..8f64eec 100644
--- a/buffet/commands/schema_utils.cc
+++ b/buffet/commands/schema_utils.cc
@@ -9,6 +9,7 @@
 #include <string>
 
 #include <base/json/json_writer.h>
+#include <chromeos/variant_dictionary.h>
 
 #include "buffet/commands/object_schema.h"
 #include "buffet/commands/prop_types.h"
@@ -201,8 +202,8 @@
   if (value->GetType() != ValueType::Object)
     return value->GetValueAsAny();
   // Special case for object types.
-  // Convert native_types::Object to chromeos::dbus_utils::Dictionary
-  chromeos::dbus_utils::Dictionary dict;
+  // Convert native_types::Object to chromeos::VariantDictionary
+  chromeos::VariantDictionary dict;
   for (const auto& pair : value->GetObject()->GetValue()) {
     // Since we are inserting the elements from native_types::Object which is
     // a map, the keys are already sorted. So use the "end()" position as a hint
@@ -227,13 +228,13 @@
   }
 
   // Special case for object types.
   // We expect the |value| to contain chromeos::dbus_utils::Dictionary, while
   // PropValue must use native_types::Object instead. Do the conversion.
-  if (!value.IsTypeCompatible<chromeos::dbus_utils::Dictionary>()) {
+  if (!value.IsTypeCompatible<chromeos::VariantDictionary>()) {
     type->GenerateErrorValueTypeMismatch(error);
     return result;
   }
-  const auto& dict = value.Get<chromeos::dbus_utils::Dictionary>();
+  const auto& dict = value.Get<chromeos::VariantDictionary>();
   native_types::Object obj;
   CHECK(nullptr != type->GetObjectSchemaPtr())
       << "An object type must have a schema defined for it";
@@ -227,13 +228,13 @@
 
   // Special case for object types.
-  // We expect the |value| to contain chromeos::dbus_utils::Dictionary, while
+  // We expect the |value| to contain chromeos::VariantDictionary, while
   // PropValue must use native_types::Object instead. Do the conversion.